BaseModel enum

Base model for AI models.

Inheritance
Available extensions

Values

sd14 → const BaseModel

Stable Diffusion 1.4

sd15 → const BaseModel

Stable Diffusion 1.5

sd15Lcm → const BaseModel

Stable Diffusion 1.5 LCM

sd15Hyper → const BaseModel

Stable Diffusion 1.5 Hyper

sd20 → const BaseModel

Stable Diffusion 2.0

sd20768 → const BaseModel

Stable Diffusion 2.0 768

sd21 → const BaseModel

Stable Diffusion 2.1

sd21768 → const BaseModel

Stable Diffusion 2.1 768

sd21Unclip → const BaseModel

Stable Diffusion 2.1 Unclip

sdxl09 → const BaseModel

Stable Diffusion XL 0.9

sdxl10 → const BaseModel

Stable Diffusion XL 1.0

sdxl10Lcm → const BaseModel

Stable Diffusion XL 1.0 LCM

sdxlDistilled → const BaseModel

Stable Diffusion XL Distilled

sdxlTurbo → const BaseModel

Stable Diffusion XL Turbo

sdxlLightning → const BaseModel

Stable Diffusion XL Lightning

sdxlHyper → const BaseModel

Stable Diffusion XL Hyper

sd3 → const BaseModel

Stable Diffusion 3

sd35 → const BaseModel

Stable Diffusion 3.5

sd35Medium → const BaseModel

Stable Diffusion 3.5 Medium

sd35Large → const BaseModel

Stable Diffusion 3.5 Large

sd35LargeTurbo → const BaseModel

Stable Diffusion 3.5 Large Turbo

pony → const BaseModel

Pony

flux1S → const BaseModel

Flux.1 S

flux1D → const BaseModel

Flux.1 D

auraFlow → const BaseModel

AuraFlow

stableCascade → const BaseModel

Stable Cascade

svd → const BaseModel

SVD

svdXt → const BaseModel

SVD XT

playgroundV2 → const BaseModel

Playground v2

pixartA → const BaseModel

PixArt a

pixartE → const BaseModel

PixArt E

hunyuan1 → const BaseModel

Hunyuan 1

hunyuanVideo → const BaseModel

Hunyuan Video

lumina → const BaseModel

Lumina

kolors → const BaseModel

Kolors

illustrious → const BaseModel

Illustrious

mochi → const BaseModel

Mochi

ltxv → const BaseModel

LTXV

cogVideoX → const BaseModel

CogVideoX

noobAI → const BaseModel

NoobAI

wanVideo → const BaseModel

Wan Video

odor → const BaseModel

ODOR

other → const BaseModel

Other base model

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
Converts this enum value to a string for API requests.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromString(String value) BaseModel
Converts a string to a BaseModel enum value.

Constants

values → const List<BaseModel>
A constant List of the values in this enum, in order of their declaration.