ContentRepository class

Repository for interacting with the Content API.

Constructors

ContentRepository(ApiClient _apiClient, {RetryPolicy? retryPolicy})
Creates a new content repository.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getContent(List<String> slug) Future<Map<String, dynamic>>
Retrieves content by slug.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited