CreateMultipartUploadParams class

Parameters for creating a multipart upload.

Constructors

CreateMultipartUploadParams({String? mimeType, String? filename, required int size})
Creates parameters for a multipart upload.
const

Properties

filename String?
The name of the file.
final
hashCode int
The hash code for this object.
no setterinherited
mimeType String?
The MIME type of the file.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
The size of the file in bytes.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts these parameters to a JSON map for the request body.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited