GetCurrentUserResponse class

Response for the current user endpoint.

Constructors

GetCurrentUserResponse({required User user})
Creates a new get current user response.
const
GetCurrentUserResponse.fromJson(Map<String, dynamic> json)
Creates a get current user response from a JSON map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
user User
The current user details.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this response to a JSON map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited