GetImagesResponse class

Response for the images endpoint.

Inheritance

Constructors

GetImagesResponse({required List<ImageModel> items, required PaginationMetadata metadata})
Creates a new get images response.
const
GetImagesResponse.fromJson(Map<String, dynamic> json)
Creates a get images response from a JSON map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
hasMore bool
Returns true if there are more pages available.
no setterinherited
items List<ImageModel>
The list of items in the current page.
finalinherited
metadata PaginationMetadata
Metadata about the pagination state.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this response to a JSON map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited