GetModelByIdParams class

Parameters for retrieving a model by ID.

Constructors

GetModelByIdParams({required int id})
Creates parameters for retrieving a model by ID.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id int
The ID of the model to retrieve.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toQueryParameters() Map<String, dynamic>
Converts these parameters to a map for use in query parameters.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited