GetModelResponse class

Response for the get model by ID endpoint.

Constructors

GetModelResponse({required Model model})
Creates a new get model response.
const
GetModelResponse.fromJson(Map<String, dynamic> json)
Creates a get model response from a JSON map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
model Model
The model details.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this response to a JSON map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited