GetModelVersionGenerationDetailsParams class

Parameters for retrieving generation details for a model version.

Constructors

GetModelVersionGenerationDetailsParams({required int id, int? epoch})
Creates parameters for retrieving generation details.
const

Properties

epoch int?
The epoch number for training models.
final
hashCode int
The hash code for this object.
no setterinherited
id int
The ID of the model version.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toQueryParameters() Map<String, dynamic>
Converts these parameters to a map for use in query parameters.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited