GetModelVersionMiniResponse class
Response for the get model version mini endpoint.
Constructors
- GetModelVersionMiniResponse({required ModelVersion modelVersion})
-
Creates a new get model version mini response.
const
-
GetModelVersionMiniResponse.fromJson(Map<
String, dynamic> json) -
Creates a get model version mini response from a JSON map.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- modelVersion → ModelVersion
-
The model version details.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this response to a JSON map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited