GetModelsParams class

Parameters for retrieving a list of models.

Inheritance

Constructors

GetModelsParams({int? limit, int? page, String? cursor, int? id, String? username, bool? nsfw, bool? primaryFileOnly, bool? favorites, bool? hidden, List<ModelType>? types, List<BaseModel>? baseModels, ModelSort? sort, MetricTimeframe? period, List<int>? tags, int? browsingLevel, bool? earlyAccess, String? query, bool? supportsGeneration, bool? archived})
Creates parameters for retrieving a list of models.
const

Properties

archived bool?
Include models with archived status.
final
baseModels List<BaseModel>?
Filter by base models.
final
browsingLevel int?
Browsing level for filtering NSFW content.
final
cursor String?
Cursor for the next page, if using cursor-based pagination.
finalinherited
earlyAccess bool?
Include early access models.
final
favorites bool?
Filter by user favorites. Requires authentication.
final
hashCode int
The hash code for this object.
no setterinherited
hidden bool?
Include hidden models. Requires authentication.
final
id int?
Filter by model ID.
final
limit int?
Maximum number of items to return per page.
finalinherited
nsfw bool?
Filter by NSFW level.
final
page int?
Page number to return, if using page-based pagination.
finalinherited
period MetricTimeframe?
Time period for metrics.
final
primaryFileOnly bool?
Only include primary files.
final
query String?
Filter by search query.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sort ModelSort?
Sort order for results.
final
supportsGeneration bool?
Only include models that support on-site generation.
final
tags List<int>?
Filter by tag IDs.
final
types List<ModelType>?
Filter by model types.
final
username String?
Filter by creator username.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toQueryParameters() Map<String, dynamic>
Converts these parameters to a map for use in query parameters.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited