GetUsersParams class

Parameters for retrieving a list of users.

Inheritance

Constructors

GetUsersParams({int? limit, int? page, String? cursor, List<int>? ids, String? username, String? query})
Creates parameters for retrieving a list of users.
const

Properties

cursor String?
Cursor for the next page, if using cursor-based pagination.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
ids List<int>?
Filter by user IDs.
final
limit int?
Maximum number of items to return per page.
finalinherited
page int?
Page number to return, if using page-based pagination.
finalinherited
query String?
Search query for users.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
username String?
Filter by username.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toQueryParameters() Map<String, dynamic>
Converts these parameters to a map for use in query parameters.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited