GetUsersResponse class

Response for the users endpoint.

Inheritance

Constructors

GetUsersResponse({required List<User> items, required PaginationMetadata metadata})
Creates a new get users response.
const
GetUsersResponse.fromJson(Map<String, dynamic> json)
Creates a get users response from a JSON map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
hasMore bool
Returns true if there are more pages available.
no setterinherited
items List<User>
The list of items in the current page.
finalinherited
metadata PaginationMetadata
Metadata about the pagination state.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this response to a JSON map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited