ImageStats class

Statistics about an image.

Constructors

ImageStats({required int cryCount, required int laughCount, required int likeCount, required int dislikeCount, required int heartCount, required int commentCount})
Creates a new image stats instance.
const
ImageStats.fromJson(Map<String, dynamic> json)
Creates an image stats instance from a JSON map.
factory

Properties

commentCount int
Number of comments.
final
cryCount int
Number of cry reactions.
final
dislikeCount int
Number of dislike reactions.
final
hashCode int
The hash code for this object.
no setterinherited
heartCount int
Number of heart reactions.
final
laughCount int
Number of laugh reactions.
final
likeCount int
Number of like reactions.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this image stats to a JSON map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited