ImagesRepository class

Repository for interacting with the Images API.

Constructors

ImagesRepository(ApiClient _apiClient, {RetryPolicy? retryPolicy})
Creates a new images repository.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getImages([GetImagesParams? params]) Future<GetImagesResponse>
Retrieves a list of images.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited