MetricTimeframe enum

Period options for filtering by time.

Inheritance
Available extensions

Values

allTime → const MetricTimeframe

All time.

year → const MetricTimeframe

Year.

month → const MetricTimeframe

Month.

week → const MetricTimeframe

Week.

day → const MetricTimeframe

Day.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
Converts this enum value to a string for API requests.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MetricTimeframe>
A constant List of the values in this enum, in order of their declaration.