ModelHashType enum

Hash type for model file hashes.

Inheritance
Available extensions

Values

sha256 → const ModelHashType

SHA-256 hash.

autoV2 → const ModelHashType

AutoV2 hash (perceptual).

blake3 → const ModelHashType

Blake3 hash.

crc32 → const ModelHashType

CRC32 hash

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
Converts this enum value to a string for API requests.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromString(String value) ModelHashType
Converts a string to a ModelHashType enum value.

Constants

values → const List<ModelHashType>
A constant List of the values in this enum, in order of their declaration.