ModelStats class

Statistics about a model.

Constructors

ModelStats({required int downloadCount, required int favoriteCount, required int commentCount, double? rating, int? ratingCount, int? tippedAmountCount})
Creates a new model stats instance.
const
ModelStats.fromJson(Map<String, dynamic> json)
Creates a model stats instance from a JSON map.
factory

Properties

commentCount int
Number of comments.
final
downloadCount int
Number of downloads.
final
favoriteCount int
Number of favorites.
final
hashCode int
The hash code for this object.
no setterinherited
rating double?
Average rating.
final
ratingCount int?
Number of ratings.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tippedAmountCount int?
Number of tips received.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this model stats to a JSON map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited