ModelsRepository class

Repository for interacting with the Models API.

Constructors

ModelsRepository(ApiClient _apiClient, {RetryPolicy? retryPolicy})
Creates a new models repository.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getModel(int id) Future<GetModelResponse>
Retrieves a model by ID.
getModels([GetModelsParams? params]) Future<GetModelsResponse>
Retrieves a list of models.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited