MultipartUploadPart class
Represents a part in a multipart upload.
Constructors
- MultipartUploadPart({required String url, required int partNumber, required int size})
-
Creates a new multipart upload part.
const
-
MultipartUploadPart.fromJson(Map<
String, dynamic> json) -
Creates a multipart upload part from a JSON map.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- partNumber → int
-
The part number.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int
-
The part size in bytes.
final
- url → String
-
The upload URL for this part.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this multipart upload part to a JSON map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited