MultipartUploadResponse class

Response for the multipart upload creation endpoint.

Constructors

MultipartUploadResponse({required String uploadId, required String key, required String uploadURL, required List<MultipartUploadPart> parts})
Creates a new multipart upload response.
const
MultipartUploadResponse.fromJson(Map<String, dynamic> json)
Creates a multipart upload response from a JSON map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
key String
The key for the uploaded file.
final
parts List<MultipartUploadPart>
The parts to upload.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uploadId String
The upload ID for the multipart upload.
final
uploadURL String
The S3 upload URL.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this response to a JSON map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited