PermissionsRepository class

Repository for interacting with the Permissions API.

Constructors

PermissionsRepository(ApiClient _apiClient, {RetryPolicy? retryPolicy})
Creates a new permissions repository.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkPermissions({EntityType entityType = EntityType.modelVersion, required List<int> entityIds, PermissionType permission = PermissionType.generate, int? userId}) Future<CheckPermissionsResponse>
Checks permissions for entities.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited