RetryConfig class

Configuration for retry behavior.

Constructors

RetryConfig({int maxRetries = 3, int baseDelayMs = 1000, int maxDelayMs = 10000, List<Type> retryableExceptions = const [CivitaiNetworkException, CivitaiTimeoutException, CivitaiServerException]})
Creates a new retry configuration.
const

Properties

baseDelayMs int
Base delay between retries in milliseconds.
final
hashCode int
The hash code for this object.
no setterinherited
maxDelayMs int
Maximum delay between retries in milliseconds.
final
maxRetries int
Maximum number of retry attempts.
final
retryableExceptions List<Type>
List of exception types that should trigger a retry.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited