UploadRepository class

Repository for interacting with the Upload API.

Constructors

UploadRepository(ApiClient _apiClient, {RetryPolicy? retryPolicy})
Creates a new upload repository.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createImageUpload() Future<ImageUploadResponse>
Creates an image upload request.
createMultipartUpload(CreateMultipartUploadParams params) Future<MultipartUploadResponse>
Creates a multipart upload request.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited