UserFilePreferences class
User's file format preferences.
Constructors
- UserFilePreferences({String? imageFormat, String? archiveFormat})
-
Creates a new user file preferences instance.
const
-
UserFilePreferences.fromJson(Map<
String, dynamic> json) -
Creates a user file preferences instance from a JSON map.
factory
Properties
- archiveFormat → String?
-
Preferred archive format.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageFormat → String?
-
Preferred image format.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts these user file preferences to a JSON map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited