UsersRepository class
Repository for interacting with the Users API.
Constructors
- UsersRepository(ApiClient _apiClient, {RetryPolicy? retryPolicy})
- Creates a new users repository.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getCurrentUser(
) → Future< GetCurrentUserResponse> - Retrieves the current authenticated user.
-
getUsers(
[GetUsersParams? params]) → Future< GetUsersResponse> - Retrieves a list of users.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited