CivitaiServerException class
Exception thrown when a request fails due to a server error (5xx).
- Inheritance
-
- Object
- CivitaiException
- CivitaiServerException
Constructors
-
CivitaiServerException(String message, [Map<
String, dynamic> ? data]) -
Creates a new server exception with the given
message.
Properties
-
data
→ Map<
String, dynamic> ? -
Original error data from the API, if available.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable error message.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited