Creator class
Represents a creator on CivitAI.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int?
-
Unique identifier for the creator.
final
- image → String?
-
URL to the creator's profile image.
final
- link → String?
-
Link to the creator's models.
final
- modelCount → int?
-
Count of models uploaded by the creator.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- username → String
-
Username of the creator.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this creator to a JSON map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited