CreatorsRepository class
Repository for interacting with the Creators API.
Constructors
- CreatorsRepository(ApiClient _apiClient, {RetryPolicy? retryPolicy})
- Creates a new creators repository.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getCreators(
[PaginationParams? params]) → Future< GetCreatorsResponse> - Retrieves a list of creators.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited