EntityType enum
Entity types for permissions.
Values
- model → const EntityType
-
Model.
- modelVersion → const EntityType
-
Model version.
- image → const EntityType
-
Image.
- post → const EntityType
-
Post.
- article → const EntityType
-
Article.
- collection → const EntityType
-
Collection.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String - Converts this enum value to a string for API requests.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromString(
String value) → EntityType - Converts a string to an EntityType enum value.
Constants
-
values
→ const List<
EntityType> - A constant List of the values in this enum, in order of their declaration.