FileType enum
File types for model files.
Values
- model → const FileType
-
Model file.
- pruned → const FileType
-
Pruned model file.
- checkpoint → const FileType
-
Checkpoint file.
- config → const FileType
-
Config file.
- vae → const FileType
-
VAE file.
- archive → const FileType
-
Archive (zip, tar, etc.) file.
- text → const FileType
-
Text file.
- code → const FileType
-
Source code file.
- trainingData → const FileType
-
Generic training data file.
- images → const FileType
-
Example images.
- textEncoder → const FileType
-
Text encoder file.
- negative → const FileType
-
Negative file.
- unknown → const FileType
-
Unknown file type.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String - Converts this enum value to a string for API requests.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromString(
String value) → FileType - Converts a string to a FileType enum value.