GetCurrentUserParams class
Parameters for retrieving the current user's profile.
Constructors
- GetCurrentUserParams({bool? includeEmail})
-
Creates parameters for retrieving the current user's profile.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- includeEmail → bool?
-
Whether to include the user's email.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toQueryParameters(
) → Map< String, dynamic> - Converts these parameters to a map for use in query parameters.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited