GetCurrentUserResponse class
Response for the current user endpoint.
Constructors
- GetCurrentUserResponse({required User user})
-
Creates a new get current user response.
const
-
GetCurrentUserResponse.fromJson(Map<
String, dynamic> json) -
Creates a get current user response from a JSON map.
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this response to a JSON map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited