GetModelByIdParams class
Parameters for retrieving a model by ID.
Constructors
- GetModelByIdParams({required int id})
-
Creates parameters for retrieving a model by ID.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toQueryParameters(
) → Map< String, dynamic> - Converts these parameters to a map for use in query parameters.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited