GetModelVersionByHashParams class
Parameters for retrieving a model version by hash.
Constructors
- GetModelVersionByHashParams({required String hash, ModelHashType hashType = ModelHashType.sha256})
-
Creates parameters for retrieving a model version by hash.
const
Properties
- hash → String
-
The hash of the model file to search for.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hashType → ModelHashType
-
The type of hash used.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toQueryParameters(
) → Map< String, dynamic> - Converts these parameters to a map for use in query parameters.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited