ModelStatus enum
Model status.
Values
- published → const ModelStatus
-
Published and visible.
- unpublished → const ModelStatus
-
Unpublished/draft.
- deleted → const ModelStatus
-
Deleted.
- tosViolation → const ModelStatus
-
TOS violation.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String - Converts this enum value to a string for API requests.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromString(
String value) → ModelStatus - Converts a string to a ModelStatus enum value.
Constants
-
values
→ const List<
ModelStatus> - A constant List of the values in this enum, in order of their declaration.