ModelType enum
Enum representing the different types of models available on CivitAI.
Values
- checkpoint → const ModelType
-
Checkpoint model.
- textualInversion → const ModelType
-
Textual Inversion embedding.
- hypernetwork → const ModelType
-
Hypernetwork.
- aestheticGradient → const ModelType
-
Aesthetic Gradient.
- lora → const ModelType
-
LoRA (Low-Rank Adaptation).
- locon → const ModelType
-
LoCon (Low-Rank Convolution).
- dora → const ModelType
-
DoRA model.
- controlnet → const ModelType
-
Controlnet model.
- upscaler → const ModelType
-
Upscaler.
- motionModule → const ModelType
-
Motion module.
- vae → const ModelType
-
VAE (Variational Auto-Encoder).
- poses → const ModelType
-
Poses.
- wildcards → const ModelType
-
Wildcards.
- workflows → const ModelType
-
Workflows.
- detection → const ModelType
-
Detection.
- other → const ModelType
-
Other type of model.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String - Converts this enum value to a string for API requests.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromString(
String value) → ModelType - Converts a string to a ModelType enum value.