ModelVersionsRepository class
Repository for interacting with the Model Versions API.
Constructors
- ModelVersionsRepository(ApiClient _apiClient, {RetryPolicy? retryPolicy})
- Creates a new model versions repository.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getModelVersion(
int id) → Future< GetModelVersionResponse> - Retrieves a model version by ID.
-
getModelVersionByHash(
String hash, [GetModelVersionByHashParams? params]) → Future< GetModelVersionByHashResponse> - Retrieves a model version by hash.
-
getModelVersionMini(
int id) → Future< GetModelVersionMiniResponse> - Retrieves a mini version of a model version by ID.
-
getModelVersionsByHashIds(
GetModelVersionsByHashIdsParams params) → Future< GetModelVersionsByHashIdsResponse> - Retrieves model versions by hash IDs.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited