PartnersRepository class
Repository for interacting with the Partners API.
Constructors
- PartnersRepository(ApiClient _apiClient, {RetryPolicy? retryPolicy})
- Creates a new partners repository.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generateToken(
) → Future< String> - Generates a partner token.
-
getSupportedModels(
) → Future< List< Map< >String, dynamic> > - Retrieves supported models for partner services.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited