Tag class
Represents a tag on CivitAI.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
Unique identifier for the tag.
final
- imageCount → int?
-
Count of images with this tag.
final
- isCategory → bool?
-
Whether this tag is a category.
final
- link → String?
-
Link to search for this tag.
final
- modelCount → int?
-
Count of models with this tag.
final
- name → String
-
Name of the tag.
final
- nsfwLevel → NsfwLevel?
-
NSFW level of the tag.
final
- postCount → int?
-
Count of posts with this tag.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this tag to a JSON map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited