VaultRepository class
Repository for interacting with the Vault API.
Constructors
- VaultRepository(ApiClient _apiClient, {RetryPolicy? retryPolicy})
- Creates a new vault repository.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
checkVault(
int versionId) → Future< bool> - Checks if a model version is in the vault.
-
getAll(
) → Future< List< Map< >String, dynamic> > - Retrieves all vaulted models for the current user.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toggleVersion(
int versionId) → Future< bool> - Toggles a model version in the vault.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited